program test
  use Statistics
  implicit none
  real, allocatable, dimension(:) :: x, y, xa, ya
  integer :: nx, er, i
  real :: a, cc, slope, intercept

  nx=0
  open(unit=10,file='data.org',status='old',iostat=er)
  do
     read(10,*,iostat=er) a, a
     if(er/=0)then
        exit
     end if
     nx=nx+1
  end do
  close(unit=10,status='keep')

  allocate(x(nx))
  allocate(y(nx))
  allocate(xa(nx))
  allocate(ya(nx))

  open(unit=11,file='data.org',status='old',iostat=er)
  do i=1,nx
     read(11,*) x(i), y(i)
  end do
  close(unit=11,status='keep')

  call Reg_Line( nx, x, y, slope, intercept )
  call Cor_Coe( nx, x, y, cc )
  call Anomaly_1d( nx, x, xa )
  call Anomaly_1d( nx, y, ya )

  open(unit=11,file='result.dat',status='unknown')
  do i=1,nx
     write(11,*) xa(i), ya(i)
  end do
  close(unit=11,status='keep')

  write(*,*) '*******************************'
  write(*,*) 'slope =', slope
  write(*,*) 'intercept =', intercept
  write(*,*) 'Cor_Coe =', cc
  write(*,*) 'data number =', nx
  write(*,*) '*******************************'

  deallocate(x)
  deallocate(y)
  deallocate(xa)
  deallocate(ya)

end program
